==> oe_python_template-0.0.2.tar.gz: oe_python_template-0.0.2/RELEASE_NOTES.md <==
[🧠 OE Python Template](https://oe-python-template.readthedocs.io/)

## [0.0.2] - 2025-03-02

### ⛰️  Features

- Various - ([5b74351](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/5b74351e71e2ca6cb7305bcabdbe802df55c4bae))
- Spike - ([21607c9](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/21607c955cd789dbee6171d287e21f45f039c392))

### 🐛 Bug Fixes

- *(Docker)* Runnability - ([164ab1f](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/164ab1fd7ec517d52587cf7f27f0051bdb6ce319))
- Initial semver - ([9f6fc12](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/9f6fc125c0e24cc0e31580de94db8beb926c8e36))
- Test - ([52faa74](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/52faa74b2d448b13dc12a4d8f706b34334643d00))
- Various - ([f99445f](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/f99445f85b346e0eb69a13c98c2ed311fd4cfafe))
- Chugging along - ([d59fa54](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/d59fa548abc38e88a4605f9588d57bbf9d70d1dc))

### 🚜 Refactor

- *(gitignore)* Section header - ([4ec3972](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/4ec39725978a1e2a3a6138136313365a7f7ee792))
- .gitignore - ([ed7d503](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/ed7d503f3c8b6ff0be55b149e1a02729b4097629))

### ⚙️ Miscellaneous Tasks

- *(SonarQube)* Wire - ([be10859](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/be108592780cc12c3e6784737a70921c8b65c966))
- Deps - ([99fba1c](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/99fba1cba195dbbf5bb14c617c1a3bd4124771c5))
- Clean post self-updating - ([4a8615a](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/4a8615a9a33d61a7b71d7a8ceff2695de6bf94bd))
- Act - ([650a1ba](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/650a1bac5a76ebafded4fda7f98e6e81cc7a8426))

## New Contributors ❤️

* @helmut-hoffer-von-ankershoffen made their first contribution

==> oe_python_template-0.1.0.tar.gz: oe_python_template-0.1.0/RELEASE_NOTES.md <==
[🧠 OE Python Template](https://oe-python-template.readthedocs.io/)

## [0.1.0](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/compare/v0.0.2..v0.1.0) - 2025-03-02

### ⚙️ Miscellaneous Tasks

- Fix in arch for docker images - ([be8de5b](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/be8de5b1d13587017cdb5b7ecc1bba63ea8245fb))


## [0.0.2] - 2025-03-02

### ⛰️  Features

- Various - ([5b74351](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/5b74351e71e2ca6cb7305bcabdbe802df55c4bae))
- Spike - ([21607c9](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/21607c955cd789dbee6171d287e21f45f039c392))

### 🐛 Bug Fixes

- *(Docker)* Runnability - ([164ab1f](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/164ab1fd7ec517d52587cf7f27f0051bdb6ce319))
- Initial semver - ([9f6fc12](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/9f6fc125c0e24cc0e31580de94db8beb926c8e36))
- Test - ([52faa74](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/52faa74b2d448b13dc12a4d8f706b34334643d00))
- Various - ([f99445f](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/f99445f85b346e0eb69a13c98c2ed311fd4cfafe))
- Chugging along - ([d59fa54](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/d59fa548abc38e88a4605f9588d57bbf9d70d1dc))

### 🚜 Refactor

- *(gitignore)* Section header - ([4ec3972](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/4ec39725978a1e2a3a6138136313365a7f7ee792))
- .gitignore - ([ed7d503](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/ed7d503f3c8b6ff0be55b149e1a02729b4097629))

### ⚙️ Miscellaneous Tasks

- *(SonarQube)* Wire - ([be10859](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/be108592780cc12c3e6784737a70921c8b65c966))
- Deps - ([99fba1c](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/99fba1cba195dbbf5bb14c617c1a3bd4124771c5))
- Clean post self-updating - ([4a8615a](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/4a8615a9a33d61a7b71d7a8ceff2695de6bf94bd))
- Act - ([650a1ba](https://github.com/helmut-hoffer-von-ankershoffen/oe-python-template/commit/650a1bac5a76ebafded4fda7f98e6e81cc7a8426))

## New Contributors ❤️

* @helmut-hoffer-von-ankershoffen made their first contribution
